SISCone: Performances

# SISCone Documentation

### Version 3.0.5

## Execution time

This figure shows the execution time as a function of the number of particles and compares it with other algorithms. It has been obtained on a 3.4 GHz Pentium® IV processor.

## Algorithm complexity

SISCone's complexity is dominated by the search for stable cones. If N is the number of particles in the event and n the number of particles in a cone, the complexity goes like

N n log(n)

dominated by the ordering of the O(n) points in the vicinity of each particle.

Note: for the version of SISCone with progressive-removal, the stable-sone search has to be repeated O(N/n) times, yielding a O(N2log(n)) complexity.

Home
Contacts: Gregory Soyez Gavin Salam